==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-spacer/translations/spacer_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>SpacerConfiguration</name>
    <message>
        <location filename="../spacerconfiguration.ui" line="14"/>
        <source>Spacer Settings</source>
        <translation>スペーサーの設定</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="20"/>
        <source>Space width:</source>
        <translation>スペースの幅:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="40"/>
        <source>Space type:</source>
        <translation>スペースのタイプ:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="57"/>
        <source>fixed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="71"/>
        <source>expandable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="34"/>
        <source>lined</source>
        <translation>線</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="35"/>
        <source>dotted</source>
        <translation>ドット</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="36"/>
        <source>invisible</source>
        <translation>見えないようにする</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.15.0.orig.tar.xz: lxqt-panel-0.15.0/plugin-spacer/translations/spacer_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>SpacerConfiguration</name>
    <message>
        <location filename="../spacerconfiguration.ui" line="14"/>
        <source>Spacer Settings</source>
        <translation>スペーサーの設定</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="20"/>
        <source>Space width:</source>
        <translation>スペースの幅:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="40"/>
        <source>Space type:</source>
        <translation>スペースのタイプ:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="57"/>
        <source>fixed</source>
        <translation>固定</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="71"/>
        <source>expandable</source>
        <translation>自動拡張</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="34"/>
        <source>lined</source>
        <translation>線</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="35"/>
        <source>dotted</source>
        <translation>ドット</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="36"/>
        <source>invisible</source>
        <translation>見えないようにする</translation>
    </message>
</context>
</TS>
